# F-ANOVA-py

A Python rewrite of [Los Alamos' functional ANOVA software](https://github.com/lanl/F-ANOVA/tree/a788d8d79d260f9223d0c70e6e785014262837bf).

Adapted by Adam C. Watts and Shankar Chawla.

---

## Installation

Install from PyPI:

```bash
pip install f-anova-py